# Developer documentation

```{include} ../../CONTRIBUTING.md
```

## Table of contents

```{toctree}
---
hidden:
---

getting-started
coding-conventions
dependency-management
data-stream
file-loading
```
